==> sale-3.1.2-58.jar: revenue/sqls/MeterCharge/getOverdueDate.sql <==
--f_oughtfee 应交金额   f_end_date 截止日期  delaypaydate 滞纳天数   delaypay 滞纳金
select 
 handplan_id,											--抄表记录id
 f_last_tablebase,										--上期指数
 f_tablebase,											--本期指数
 h.f_hand_date,											--抄表日期
 h.f_input_date,
 h.f_user_id,
 f_surplus_gas,
 f_haircut_gas,
 convert(decimal(18,2),f_oughtamount) f_oughtamount,	--应交气量
 convert(decimal(18,2),f_share_gas) f_share_gas,		--承担量
 convert(decimal(18,2),f_oughtfee) f_oughtfee,			--应交金额
 convert(decimal(18,2),f_totalowe_gas) f_totalowe_gas,
 convert(decimal(18,2),f_totalowe_fee) f_totalowe_fee,
 f_whether_pay,											--是否缴费			
 f_end_date,											--截止日期
 case when overduedays<=0 or (f_oughtamount + f_totalowe_gas) < 0 then 0 else overduedays end overduedays,	--滞纳天数
 h.f_balance,    --余额
  --滞纳金 
 --滞纳金=滞纳金比率*滞纳天数*欠费金额
 --滞纳金小于0时：返回0；滞纳金大于欠费金额时，返回f_oughtfee；滞纳金大于0小于欠费金额时，返回滞纳金；
 convert(decimal(18,2),case when overduedays<=0 then 0
	  else (
			case when f_oughtamount + f_totalowe_gas<0 then 0 
				 else  (
						case when f_totalowe_gas<0 then 
								 case when overduedays*zhinajinbilv*(f_oughtfee + f_totalowe_fee-f_balance)>=f_oughtfee + f_totalowe_fee-f_balance
									  then f_oughtfee + f_totalowe_fee-f_balance
									  else overduedays*zhinajinbilv*(f_oughtfee + f_totalowe_fee-f_balance) end
							 else 
								 case when overduedays*zhinajinbilv*f_oughtfee>=f_oughtfee
									  then f_oughtfee
									  else overduedays*zhinajinbilv*f_oughtfee end
							 end
						)
				 end
	       )
	  end)+isnull(f_overdue,0) overdue,

 isnull(s.splitNum, 0) as splitNum
from(
 select h1.*,u.f_balance from (
 select 
	 id as handplan_id,
	 f_last_tablebase,		
	 f_tablebase,			
	 f_hand_date as f_hand_date,	
	 f_input_date,
	 f_oughtamount,			
	 f_oughtfee,		
	 f_whether_pay,				
	 f_end_date,
	 f_user_id,
	 f_surplus_gas,
	 f_haircut_gas,
	 f_share_gas,
	 f_totalowe_fee,
	 f_totalowe_gas,
	 f_overdue,
	 f_userinfo_id,		
	 DATEDIFF(dd,f_end_date,'{endDate} 23:59:59')+1 overduedays, --滞纳天数
	 case when f_user_type='民用' then (select cast(value as float) from  t_singlevalue where name='民用违约金') else 
	 (select cast(value as float) from  t_singlevalue where name='非民用违约金') end zhinajinbilv							   --滞纳金比率
from V_handplan 
where f_user_id = '{f_user_id}' and f_whether_pay='否' and f_meter_state = '已抄表'
)  h1
 join
(select f_balance,f_userinfo_id from t_userinfo) u on u.f_userinfo_id=h1.f_userinfo_id
) h 
left join 
(select MIN(f_hand_date) f_hand_date,f_user_id from V_handplan
where f_whether_pay='否' and f_meter_state = '已抄表'
 group by f_user_id
) h1 on h.f_user_id=h1.f_user_id
left join 
(
	select f_meter_id,count(*) as splitNum from t_userfiles where f_meter_id = '{f_user_id}' group by f_meter_id
) s
on h.f_user_id = s.f_meter_id
order by h.f_hand_date

==> sale-3.1.7-16.jar: revenue/sqls/MeterCharge/getOverdueDate.sql <==
--f_oughtfee 应交金额   f_end_date 截止日期  delaypaydate 滞纳天数   delaypay 滞纳金
select 
 handplan_id,											--抄表记录id
 f_last_tablebase,										--上期指数
 f_tablebase,											--本期指数
 h.f_hand_date,											--抄表日期
 h.f_input_date,
 h.f_user_id,
 f_surplus_gas,
 f_haircut_gas,
 convert(decimal(18,2),f_oughtamount) f_oughtamount,	--应交气量
 convert(decimal(18,2),f_share_gas) f_share_gas,		--承担量
 convert(decimal(18,2),f_oughtfee) f_oughtfee,			--应交金额
 convert(decimal(18,2),f_totalowe_gas) f_totalowe_gas,
 convert(decimal(18,2),f_totalowe_fee) f_totalowe_fee,
 f_whether_pay,											--是否缴费			
 f_end_date,											--截止日期
 case when overduedays<=0 or (f_oughtamount + f_totalowe_gas) < 0 then 0 else overduedays end overduedays,	--滞纳天数
 h.f_balance,    --余额
  --滞纳金 
 --滞纳金=滞纳金比率*滞纳天数*欠费金额
 --滞纳金小于0时：返回0；滞纳金大于欠费金额时，返回f_oughtfee；滞纳金大于0小于欠费金额时，返回滞纳金；
 convert(decimal(18,2),case when overduedays<=0 then 0
	  else (
			case when f_oughtamount + f_totalowe_gas<0 then 0 
				 else  (
						case when f_totalowe_gas<0 then 
								 case when overduedays*zhinajinbilv*(f_oughtfee + f_totalowe_fee-f_balance)>=f_oughtfee + f_totalowe_fee-f_balance
									  then f_oughtfee + f_totalowe_fee-f_balance
									  else overduedays*zhinajinbilv*(f_oughtfee + f_totalowe_fee-f_balance) end
							 else 
								 case when overduedays*zhinajinbilv*f_oughtfee>=f_oughtfee
									  then f_oughtfee
									  else overduedays*zhinajinbilv*f_oughtfee end
							 end
						)
				 end
	       )
	  end)+isnull(f_overdue,0) overdue,

 isnull(s.splitNum, 0) as splitNum
from(
 select h1.*,u.f_balance,case when u.f_balance<0 then 0 else u.f_balance end f_balances from (
 select 
	 id as handplan_id,
	 f_last_tablebase,		
	 f_tablebase,			
	 f_hand_date as f_hand_date,	
	 f_input_date,
	 f_oughtamount,			
	 f_oughtfee,		
	 f_whether_pay,				
	 f_end_date,
	 f_user_id,
	 f_surplus_gas,
	 f_haircut_gas,
	 f_share_gas,
	 f_totalowe_fee,
	 f_totalowe_gas,
	 f_overdue,
	 f_userinfo_id,		
	 DATEDIFF(dd,f_end_date,'{endDate} 23:59:59')+1 overduedays, --滞纳天数
	 case when f_user_type='民用' then (select cast(value as float) from  t_singlevalue where name='民用违约金') else 
	 (select cast(value as float) from  t_singlevalue where name='非民用违约金') end zhinajinbilv							   --滞纳金比率
from V_handplan 
where f_user_id = '{f_user_id}' and f_whether_pay='否' and f_meter_state = '已抄表'
)  h1
 join
(select f_balance,f_userinfo_id from t_userinfo) u on u.f_userinfo_id=h1.f_userinfo_id
) h 
left join 
(select MIN(f_hand_date) f_hand_date,f_user_id from V_handplan
where f_whether_pay='否' and f_meter_state = '已抄表'
 group by f_user_id
) h1 on h.f_user_id=h1.f_user_id
left join 
(
	select f_meter_id,count(*) as splitNum from t_userfiles where f_meter_id = '{f_user_id}' group by f_meter_id
) s
on h.f_user_id = s.f_meter_id
order by h.f_hand_date
